
% Realimentao de estado com
% Regulador Linear Quadrtico

% Aumentando a agressividade do controle

% Seja a planta
G  = zpk([],[0,-1],1);
S  = ss(G);

% Discretizao
T = 0.1;
Sd = c2d(S,0.1,'zoh');

Phi   = Sd.a;
Gamma = Sd.b;
C     = Sd.c;

% Acesso ao estado
Sdx = ss(Phi,Gamma,eye(2),zeros(2,1),T);

% Matrizes de Peso
Q = C'*C;
R = 1;

% Projeto do RLQ
[K,X,zc] = dlqr(Phi,Gamma,Q,R);

% Simulao Base
sim('ex_sf_rlq_sim');
tbsim = tsim; xbsim = xsim; ubsim = usim;

Qweight = [2:20];
ttsim =zeros(length(tbsim),length(Qweight));
xxsim =zeros(length(tbsim),2,length(Qweight));
uusim =zeros(length(tbsim),length(Qweight));
for i=1:length(Qweight)
    Q = Qweight(i)*C'*C;
    [K,X,zc] = dlqr(Phi,Gamma,Q,R);
    sim('ex_sf_rlq_sim')
    ttsim(:,i) = tsim; xxsim(:,:,i) = xsim; uusim(:,i) = usim;
end

% Grficos
figure(2); clf
stairs(tbsim,xbsim(:,1),'-b','linewidth',3)
axis([0 7 -5 1])
hold on
stairs(tbsim,xbsim(:,2),'-r','linewidth',3)
stairs(tbsim,ubsim,'-k','linewidth',3)
grid
legend('x_{1}(t) = y(t)','x_{2}(t) = dy(t)/dt','u(t)')
xlabel('t (s)')
ylabel('x(t)')
title('RLQ mais agressivo')
for i=1:length(Qweight)
    %stairs(ttsim(:,i),xxsim(:,2,i),'-r')
    stairs(ttsim(:,i),xxsim(:,1,i),'-b')
    stairs(ttsim(:,i),uusim(:,i),'-k');
    tit=sprintf('RLQ com Q x %d',Qweight(i));
    title(tit)
    figure(2); drawnow; pause(1)
end
hold off
    
